pub struct Batch { /* private fields */ }Expand description
Jobs that run side by side and are tracked together; from
Queue::batch. The first job that fails for good cancels the batch
(jobs that haven’t run are skipped) unless Batch::allow_failures.
Implementations