#[non_exhaustive]pub struct QueueStats {
pub queues: Vec<QueueCounts>,
pub oldest_wait: Option<i64>,
pub done_last_hour: i64,
pub failed_last_hour: i64,
pub failed_total: i64,
}Expand description
The queue at a glance; from Queue::stats.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.queues: Vec<QueueCounts>One entry per queue that has jobs, by name.
oldest_wait: Option<i64>Seconds the oldest ready job has waited.
done_last_hour: i64Jobs finished in the last hour.
failed_last_hour: i64Jobs that failed for good in the last hour.
failed_total: i64Rows in failed_jobs, of any age.