Htmx

Struct Htmx 

#[non_exhaustive]
pub struct Htmx { pub request: bool, pub boosted: bool, pub target: Option<String>, pub trigger: Option<String>, pub current_url: Option<String>, }
What HTMX told us about the current request.

async fn index(htmx: Htmx) -> View {
    let page = view("products/index.html", context! {});
    if htmx.request { page.fragment("list") } else { page }
}

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
request: bool

The request was made by HTMX (HX-Request).

boosted: bool

The request comes from an hx-boost link or form, which expects a full page.

target: Option<String>

The id of the target element (HX-Target).

trigger: Option<String>

The id of the element that triggered the request (HX-Trigger).

current_url: Option<String>

The browser’s current URL (HX-Current-URL).

Implementations

Source

impl Htmx

pub fn from_headers(headers: &HeaderMap) -> Self

Reads the htmx request headers.

pub fn redirect(&self, to: &str) -> Response

Goes to to after a form post: HX-Redirect for htmx requests (a full page load in the browser), a 303 See Other otherwise.

pub fn wants_fragment(&self) -> bool

An HTMX request that wants a fragment rather than a full page.