pub struct View { /* private fields */ }Expand description
A template response, rendered by Renox with the request’s globals:
app (with the request’s app.locale), request, auth (auth.check,
auth.user), t(), can(), flash, errors, error(), old(),
csrf_token, csrf_field() and renox_head().
async fn index() -> View {
view("products/index.html", context! { products => list }).fragment("list")
}Implementations
Sourceimpl View
impl View
Sourcepub fn fragment(self, block: impl Into<String>) -> Self
pub fn fragment(self, block: impl Into<String>) -> Self
For HTMX requests (except hx-boost), render only this {% block %}.
Sourcepub fn also(self, block: impl Into<String>) -> Self
pub fn also(self, block: impl Into<String>) -> Self
For the same HTMX requests, also render block after the fragment,
to update other parts of the page in one response: give the block’s
root element an id and hx-swap-oob="true" and htmx swaps it into
the element with that id.
{% block row %}<tr id="order-{{ order.id }}">…</tr>{% endblock %}
{% block count %}<span id="order-count" hx-swap-oob="true">{{ count }}</span>{% endblock %}view("orders/index.html", ctx).fragment("row").also("count")
Sourcepub fn status(self, status: StatusCode) -> Self
pub fn status(self, status: StatusCode) -> Self
The response status (200 by default).